@@ -9,7 +9,7 @@ fi
 skalibs_tag="v2.14.3.0"
 execline_tag="v2.9.6.1"
 s6_tag="v2.13.1.0"
-oblibs_tag="0.3.3.0"
+oblibs_tag="0.3.4.0"
 
 check_tag(){
 
@@ -70,10 +70,10 @@ build_oblibs() {
 
     check_tag "${oblibs_tag}"
 
-    ./configure \
-        --prefix=/usr
+    meson setup builddir -D prefix=/usr || return 1
+    meson compile -C builddir || return 1
+    meson install -C builddir || return 1
 
-    make install || return 1
     cd ..
 }
 
