@@ -23,6 +23,8 @@
 #define SS_SYSTEM_LEN (sizeof SS_SYSTEM - 1)
 #define SS_TREE_CURRENT "current"
 #define SS_TREE_CURRENT_LEN (sizeof SS_TREE_CURRENT - 1)
+#define SS_CURRENT SS_TREE_CURRENT
+#define SS_CURRENT_LEN SS_TREE_CURRENT_LEN
 #define SS_MODULE "module"
 #define SS_MODULE_LEN (sizeof SS_MODULE - 1)
 #define SS_SCANDIR "scandir"
@@ -84,8 +86,7 @@
 #define SS_SYM_VERSION "/version"
 #define SS_SYM_VERSION_LEN (sizeof SS_SYM_VERSION - 1)
 
-#define SS_SERVICE_VERSION_NDOT 2
-#define SS_SYSTEM_VERSION_NDOT 3
+#define SS_SERVICE_VERSION_MAXLEN 50
 
 #define SS_EVENTDIR "/event"
 #define SS_EVENTDIR_LEN (sizeof SS_EVENTDIR - 1)
