@@ -48,15 +48,17 @@ struct resolve_service_addon_dependencies_s
     uint32_t optsdeps ; // string, optional dependencies
     uint32_t contents ; // string
     uint32_t provide ; // string
+    uint32_t conflict ; // string
 
     uint32_t ndepends ; // integer
     uint32_t nrequiredby ; // integer
     uint32_t noptsdeps ; // integer
     uint32_t ncontents ; // integer
     uint32_t nprovide ; // integer
+    uint32_t nconflict ; // integer
 } ;
 
-#define RESOLVE_SERVICE_ADDON_DEPENDENCIES_ZERO { 0,0,0,0,0,0,0,0,0,0 }
+#define RESOLVE_SERVICE_ADDON_DEPENDENCIES_ZERO { 0,0,0,0,0,0,0,0,0,0,0,0 }
 
 typedef struct resolve_service_addon_timeout_s resolve_service_addon_timeout_t, *resolve_service_addon_timeout_t_ref ;
 struct resolve_service_addon_timeout_s
@@ -86,14 +88,23 @@ struct resolve_service_addon_execute_s
     resolve_service_addon_timeout_t timeout ;
     uint32_t down ; // integer
     uint32_t downsignal ; // integer
+    uint32_t blockprivileges ; // integer
+    uint32_t umask ; // integer
+    uint32_t want_umask ; // integer
+    uint32_t nice ; // integer
+    uint32_t want_nice ; // integer
+    uint32_t chdir ; // string
+    uint32_t capsbound ; // string
+    uint32_t capsambient ; // string
+    uint32_t ncapsbound ; // integer
+    uint32_t ncapsambient ; // integer
 } ;
 
 #define RESOLVE_SERVICE_ADDON_EXECUTE_ZERO { \
     RESOLVE_SERVICE_ADDON_SCRIPTS_ZERO, \
     RESOLVE_SERVICE_ADDON_SCRIPTS_ZERO, \
     RESOLVE_SERVICE_ADDON_TIMEOUT_ZERO, \
-    0, \
-    0 \
+    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 \
 }
 
 typedef struct resolve_service_addon_live_s resolve_service_addon_live_t, *resolve_service_addon_live_t_ref ;
@@ -118,7 +129,6 @@ struct resolve_service_addon_logger_s
 {
     // logger
     uint32_t name ; // string, typically "name-log" or 0 if it's the resolve of the logger
-    //uint32_t destination ; // string
     uint32_t backup ; // integer
     uint32_t maxsize ; // integer
     /** integer, default 3 which mean not touched, in this case the value configured
@@ -168,29 +178,52 @@ struct resolve_service_addon_regex_s
  * StdOut: default -> /var/log/66/<service>/current through s6-log
  * StdErr: default -> inherit from StdOut
  **/
-typedef struct IO_type_s IO_type_t, *IO_type_t_ref ;
-struct IO_type_s {
+typedef struct resolve_service_addon_io_type_s resolve_service_addon_io_type_t, *resolve_service_addon_io_type_t_ref ;
+struct resolve_service_addon_io_type_s {
 
     uint32_t type  ; // integer, flags
     uint32_t destination ; // string
 } ;
 
-#define IO_TYPE_ZERO { 0, 0 }
+#define RESOLVE_SERVICE_ADDON_IO_TYPE_ZERO { 0, 0 }
 
-typedef struct IO_redirection_s IO_redirection_t, *IO_redirection_t_ref ;
-struct IO_redirection_s
+typedef struct resolve_service_addon_io_s resolve_service_addon_io_t, *resolve_service_addon_io_t_ref ;
+struct resolve_service_addon_io_s
 {
-    IO_type_t fdin ; // default close
-    IO_type_t fdout ; // default s6-log
-    IO_type_t fderr ; // default inherit
+    resolve_service_addon_io_type_t fdin ; // default close
+    resolve_service_addon_io_type_t fdout ; // default s6-log
+    resolve_service_addon_io_type_t fderr ; // default inherit
 } ;
 
-#define IO_REDIRECTION_ZERO { \
+#define RESOLVE_SERVICE_ADDON_IO_ZERO { \
     { E_PARSER_IO_TYPE_NOTSET, 0 }, \
     { E_PARSER_IO_TYPE_NOTSET, 0 }, \
     { E_PARSER_IO_TYPE_NOTSET, 0 } \
 }
 
+typedef struct resolve_service_addon_limit_s resolve_service_addon_limit_t, *resolve_service_addon_limit_t_ref;
+struct resolve_service_addon_limit_s
+{
+    // all integer
+    uint64_t limitas ;        // RLIMIT_AS (address space/virtual memory)
+    uint64_t limitcore ;      // RLIMIT_CORE (core dump size)
+    uint64_t limitcpu ;       // RLIMIT_CPU (CPU time)
+    uint64_t limitdata ;      // RLIMIT_DATA (data segment size)
+    uint64_t limitfsize ;     // RLIMIT_FSIZE (file size)
+    uint64_t limitlocks ;     // RLIMIT_LOCKS (file locks)
+    uint64_t limitmemlock ;   // RLIMIT_MEMLOCK (locked memory)
+    uint64_t limitmsgqueue ;  // RLIMIT_MSGQUEUE (POSIX message queues)
+    uint64_t limitnice ;      // RLIMIT_NICE (nice value/priority)
+    uint64_t limitnofile ;    // RLIMIT_NOFILE (open file descriptors)
+    uint64_t limitnproc ;     // RLIMIT_NPROC (number of processes)
+    uint64_t limitrtprio ;    // RLIMIT_RTPRIO (real-time priority)
+    uint64_t limitrttime ;    // RLIMIT_RTTIME (real-time CPU time)
+    uint64_t limitsigpending ;// RLIMIT_SIGPENDING (queued signals)
+    uint64_t limitstack ;     // RLIMIT_STACK (stack size)
+} ;
+
+#define RESOLVE_SERVICE_ADDON_LIMIT_ZERO { 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 }
+
 typedef struct resolve_service_s resolve_service_t, *resolve_service_t_ref ;
 struct resolve_service_s
 {
@@ -222,8 +255,8 @@ struct resolve_service_s
     resolve_service_addon_logger_t logger ;
     resolve_service_addon_environ_t environ ;
     resolve_service_addon_regex_t regex ;
-
-    IO_redirection_t io ;
+    resolve_service_addon_io_t io ;
+    resolve_service_addon_limit_t limit ;
 } ;
 
 #define RESOLVE_SERVICE_ZERO { STRALLOC_ZERO, 0, \
@@ -235,7 +268,8 @@ struct resolve_service_s
                                RESOLVE_SERVICE_ADDON_LOGGER_ZERO, \
                                RESOLVE_SERVICE_ADDON_ENVIRON_ZERO, \
                                RESOLVE_SERVICE_ADDON_REGEX_ZERO, \
-                               IO_REDIRECTION_ZERO }
+                               RESOLVE_SERVICE_ADDON_IO_ZERO, \
+                               RESOLVE_SERVICE_ADDON_LIMIT_ZERO }
 
 
 extern const resolve_service_t service_resolve_zero ;
@@ -255,7 +289,7 @@ extern int service_endof_dir(char const *dir, char const *name) ;
 extern int service_frontend_path(stralloc *sasrc,char const *sv, uid_t owner,char const *directory_forced, char const **exclude, uint8_t exlen) ;
 extern int service_frontend_src(stralloc *sasrc, char const *name, char const *src, char const **exclude) ;
 extern int service_is_g(char const *name, uint32_t flag) ;
-extern int service_get_treename(char *atree, char const *name, uint32_t flag) ;
+extern int service_get_treename(char *atree, char const *name) ;
 extern void service_resolve_sanitize(resolve_service_t *res) ;
 extern int service_resolve_get_field_tosa(stralloc *sa, resolve_service_t *res, resolve_service_enum_table_t table) ;
 extern void service_resolve_modify_field(resolve_service_t *res, resolve_service_enum_table_t table, char const *data) ;
