@@ -28,7 +28,6 @@
 #include <skalibs/stralloc.h>
 #include <skalibs/cdb.h>
 
-
 #include <66/ssexec.h>
 #include <66/tree.h>
 #include <66/resolve.h>
@@ -67,33 +66,6 @@ static void conf_init(conf_t *conf)
 
 }
 
-static void set_info(ssexec_t *info)
-{
-    log_flow() ;
-
-    int r ;
-
-    set_treeinfo(info) ;
-
-    r = set_livedir(&info->live) ;
-    if (!r)
-        log_die_nomem("stralloc") ;
-    if(r < 0)
-        log_die(LOG_EXIT_SYS, "live: ", info->live.s, " must be an absolute path") ;
-
-    if (!stralloc_copy(&info->scandir, &info->live))
-        log_die_nomem("stralloc") ;
-
-    r = set_livescan(&info->scandir, info->owner) ;
-    if (!r)
-        log_die_nomem("stralloc") ;
-    if(r < 0)
-        log_die(LOG_EXIT_SYS, "scandir: ", info->scandir.s, " must be an absolute path") ;
-
-    if (!set_environment(&info->environment, info->owner))
-        log_dieusys(LOG_EXIT_ZERO, "set environment") ;
-}
-
 static int resolve_find_cdb_0721(stralloc *result, cdb const *c, char const *key)
 {
     uint32_t x = 0 ;
@@ -391,9 +363,12 @@ static void migrate_frontend_file_0721(const char *file, ssexec_t *info)
     }
 
     {
+        resolve_enum_table_t table = E_TABLE_PARSER_SECTION_LOGGER_ZERO ;
+        table.u.parser.id = E_PARSER_SECTION_LOGGER_DESTINATION ;
+
         _alloc_stk_(store, frontend.len + 1) ;
         _alloc_stk_(stdout, frontend.len + 22) ;
-        int r = parse_get_value_of_key(&store, frontend.s, SECTION_LOG, list_section_logger, KEY_LOGGER_DESTINATION) ;
+        int r = parse_get_value_of_key(&store, frontend.s, table) ;
         if (r) {
             log_1_warn("Destination field is deprecated -- convert it automatically to StdOut=s6log:", store.s) ;
             auto_strings(stdout.s, "StdOut=s6log:", store.s, "\n\n[Start]") ;
@@ -480,7 +455,6 @@ static void migrate_user_service(ssexec_t *info)
     }
 }
 
-
 static void migrate_service_0721(void)
 {
     log_flow() ;
@@ -610,41 +584,12 @@ static void migrate_service_0721(void)
     ssexec_free(&info) ;
 }
 
-static void migrate_create_snap_0721(ssexec_t *info)
-{
-    int argc = 4 ;
-    int m = 0 ;
-    char const *prog = PROG ;
-    char const *newargv[argc] ;
-
-    char const *help = info->help ;
-    char const *usage = info->usage ;
-
-    info->help = help_snapshot_create ;
-    info->usage = usage_snapshot_create ;
-
-    newargv[m++] = "snapshot" ;
-    newargv[m++] = "-s" ;
-    newargv[m++] = "system@0.7.2.1" ;
-    newargv[m] = 0 ;
-
-    PROG = "snapshot" ;
-    if (ssexec_snapshot_create(m, newargv, info))
-        log_dieu(LOG_EXIT_SYS, "create snapshot system@0.7.2.1") ;
-    PROG = prog ;
-
-    info->help = help ;
-    info->usage = usage ;
-
-}
 void migrate_0721(ssexec_t *info)
 {
     log_flow() ;
 
     log_info("Upgrading system from version: 0.7.2.1 to: ", SS_VERSION) ;
 
-    migrate_create_snap_0721(info) ;
-
     migrate_tree_0721(info) ;
 
     migrate_service_0721() ;
