@@ -88,6 +88,10 @@ int parse_contents(resolve_service_t *res, char const *str)
                 if (!parse_section_regex(res, tmp))
                     log_warnu_return(LOG_EXIT_ZERO,"parse section: ", secname, " of service: ", res->sa.s + res->name) ;
                 break;
+            case E_PARSER_SECTION_EXECUTE:
+                if (!parse_section_execute(res, tmp))
+                    log_warnu_return(LOG_EXIT_ZERO,"parse section: ", secname, " of service: ", res->sa.s + res->name) ;
+                break;
 
             default:
                 /* never happen*/
