@@ -17,10 +17,9 @@
 
 #include <oblibs/log.h>
 #include <oblibs/string.h>
+#include <oblibs/hash.h>
 
 #include <66/service.h>
-#include <66/hash.h>
-
 #include <66/resolve.h>
 
 int hash_add(struct resolve_hash_s **hash, char const *name, resolve_service_t res)
@@ -68,3 +67,10 @@ void hash_free(struct resolve_hash_s **hash)
 		free(c) ;
 	}
 }
+
+void hash_reset_visit(struct resolve_hash_s *hash)
+{
+    struct resolve_hash_s *c, *tmp ;
+    HASH_ITER(hh, hash, c, tmp)
+        c->visit = 0 ;
+}
\ No newline at end of file
