@@ -181,6 +181,10 @@ static int get_deps(stralloc *sa, resolve_service_t *res, resolve_service_enum_d
             str = res->sa.s + res->dependencies.provide ;
             break ;
 
+        case E_RESOLVE_SERVICE_DEPS_CONFLICT:
+            str = res->sa.s + res->dependencies.conflict ;
+            break ;
+
         case E_RESOLVE_SERVICE_DEPS_NDEPENDS:
             fmt[uint32_fmt(fmt,res->dependencies.ndepends)] = 0 ;
             str = fmt ;
@@ -206,6 +210,11 @@ static int get_deps(stralloc *sa, resolve_service_t *res, resolve_service_enum_d
             str = fmt ;
             break ;
 
+        case E_RESOLVE_SERVICE_DEPS_NCONFLICT:
+            fmt[uint32_fmt(fmt,res->dependencies.nconflict)] = 0 ;
+            str = fmt ;
+            break ;
+
         default:
             return e ;
     }
@@ -279,6 +288,43 @@ static int get_exec(stralloc *sa, resolve_service_t *res, resolve_service_enum_e
             str = fmt ;
             break ;
 
+        case E_RESOLVE_SERVICE_EXECUTE_BLOCK_PRIVILEGES:
+            fmt[uint32_fmt(fmt,res->execute.blockprivileges)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_UMASK:
+            fmt[uint32_fmt(fmt,res->execute.umask)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_WANT_UMASK:
+            fmt[uint32_fmt(fmt,res->execute.want_umask)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_NICE:
+            fmt[uint32_fmt(fmt,res->execute.nice)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_WANT_NICE:
+            fmt[uint32_fmt(fmt,res->execute.want_nice)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_CHDIR:
+            str = res->sa.s + res->execute.chdir ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_CAPS_BOUND:
+            str = res->sa.s + res->execute.capsbound ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_CAPS_AMBIENT:
+            str = res->sa.s + res->execute.capsambient ;
+            break ;
+
         default:
             return e ;
     }
@@ -515,7 +561,7 @@ static int get_regex(stralloc *sa, resolve_service_t *res, resolve_service_enum_
     return e ;
 }
 
-static int get_io(stralloc *sa, resolve_service_t *res, resolve_service_enum_io_t table)
+static int get_io(stralloc *sa, resolve_service_t *res, resolve_service_enum_limit_t table)
 {
     log_flow() ;
 
@@ -563,6 +609,103 @@ static int get_io(stralloc *sa, resolve_service_t *res, resolve_service_enum_io_
     return e ;
 }
 
+static int get_limit(stralloc *sa, resolve_service_t *res, resolve_service_enum_limit_t table)
+{
+    log_flow() ;
+
+    char fmt[UINT64_FMT] ;
+    char const *str = 0 ;
+    int e = 0 ;
+
+    switch(table) {
+
+        case E_RESOLVE_SERVICE_LIMIT_AS:
+            fmt[uint64_fmt(fmt,res->limit.limitas)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_CORE:
+            fmt[uint64_fmt(fmt,res->limit.limitcore)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_CPU:
+            fmt[uint64_fmt(fmt,res->limit.limitcpu)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_DATA:
+            fmt[uint64_fmt(fmt,res->limit.limitdata)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_FSIZE:
+            fmt[uint64_fmt(fmt,res->limit.limitfsize)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_LOCKS:
+            fmt[uint64_fmt(fmt,res->limit.limitlocks)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_MEMLOCK:
+            fmt[uint64_fmt(fmt,res->limit.limitmemlock)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_MSGQUEUE:
+            fmt[uint64_fmt(fmt,res->limit.limitmsgqueue)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_NICE:
+            fmt[uint64_fmt(fmt,res->limit.limitnice)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_NOFILE:
+            fmt[uint64_fmt(fmt,res->limit.limitnofile)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_NPROC:
+            fmt[uint64_fmt(fmt,res->limit.limitnproc)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_RTPRIO:
+            fmt[uint64_fmt(fmt,res->limit.limitrtprio)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_RTTIME:
+            fmt[uint64_fmt(fmt,res->limit.limitrttime)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_SIGPENDING:
+            fmt[uint64_fmt(fmt,res->limit.limitsigpending)] = 0 ;
+            str = fmt ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_STACK:
+            fmt[uint64_fmt(fmt,res->limit.limitstack)] = 0 ;
+            str = fmt ;
+            break ;
+
+
+        default:
+            return e ;
+    }
+
+    if (!auto_stra(sa,str))
+        return e ;
+
+    e = 1 ;
+    return e ;
+}
+
 int service_resolve_get_field_tosa(stralloc *sa, resolve_service_t *res, resolve_service_enum_table_t table)
 {
     log_flow() ;
@@ -596,6 +739,9 @@ int service_resolve_get_field_tosa(stralloc *sa, resolve_service_t *res, resolve
         case E_RESOLVE_SERVICE_CATEGORY_IO:
             return get_io(sa, res, table.id) ;
 
+        case E_RESOLVE_SERVICE_CATEGORY_LIMIT:
+            return get_limit(sa, res, table.id) ;
+
         default:
             return 0 ;
     }
