@@ -21,6 +21,17 @@
 #include <66/service.h>
 #include <66/enum_service.h>
 
+static uint64_t resolve_add_uint64(char const *data)
+{
+    uint64_t u ;
+
+    if (!data)
+        data = "0" ;
+    if (!uint640_scan(data, &u))
+        return 0 ;
+    return u ;
+}
+
 static uint32_t resolve_add_uint(char const *data)
 {
     uint32_t u ;
@@ -170,6 +181,10 @@ static void modify_deps(resolve_service_t *res, char const *data, uint32_t field
             res->dependencies.provide = resolve_add_string(wres, data) ;
             break ;
 
+        case E_RESOLVE_SERVICE_DEPS_CONFLICT:
+            res->dependencies.conflict = resolve_add_string(wres, data) ;
+            break ;
+
         case E_RESOLVE_SERVICE_DEPS_NDEPENDS:
             res->dependencies.ndepends = resolve_add_uint(data) ;
             break ;
@@ -190,6 +205,10 @@ static void modify_deps(resolve_service_t *res, char const *data, uint32_t field
             res->dependencies.nprovide = resolve_add_uint(data) ;
             break ;
 
+        case E_RESOLVE_SERVICE_DEPS_NCONFLICT:
+            res->dependencies.nconflict = resolve_add_uint(data) ;
+            break ;
+
         default:
             break ;
     }
@@ -253,6 +272,38 @@ static void modify_execute(resolve_service_t *res, char const *data, uint32_t fi
             res->execute.downsignal = resolve_add_uint(data) ;
             break ;
 
+        case E_RESOLVE_SERVICE_EXECUTE_BLOCK_PRIVILEGES:
+            res->execute.blockprivileges = resolve_add_uint(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_UMASK:
+            res->execute.umask = resolve_add_uint(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_WANT_UMASK:
+            res->execute.want_umask = resolve_add_uint(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_NICE:
+            res->execute.nice = resolve_add_uint(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_WANT_NICE:
+            res->execute.want_nice = resolve_add_uint(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_CHDIR:
+            res->execute.chdir = resolve_add_string(wres, data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_CAPS_BOUND:
+            res->execute.capsbound = resolve_add_string(wres, data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_EXECUTE_CAPS_AMBIENT:
+            res->execute.capsambient = resolve_add_string(wres, data) ;
+            break ;
+
         default:
             break ;
     }
@@ -492,6 +543,81 @@ static void modify_io(resolve_service_t *res, char const *data, uint32_t field)
     free(wres) ;
 }
 
+static void modify_limit(resolve_service_t *res, char const *data, uint32_t field)
+{
+    log_flow() ;
+
+    resolve_wrapper_t_ref wres = resolve_set_struct(DATA_SERVICE, res) ;
+
+    switch (field) {
+
+        case E_RESOLVE_SERVICE_LIMIT_AS:
+            res->limit.limitas = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_CORE:
+            res->limit.limitcore = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_CPU:
+            res->limit.limitcpu = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_DATA:
+            res->limit.limitdata = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_FSIZE:
+            res->limit.limitfsize = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_LOCKS:
+            res->limit.limitlocks = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_MEMLOCK:
+            res->limit.limitmemlock = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_MSGQUEUE:
+            res->limit.limitmsgqueue = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_NICE:
+            res->limit.limitnice = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_NOFILE:
+            res->limit.limitnofile = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_NPROC:
+            res->limit.limitnproc = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_RTPRIO:
+            res->limit.limitrtprio = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_RTTIME:
+            res->limit.limitrttime = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_SIGPENDING:
+            res->limit.limitsigpending = resolve_add_uint64(data) ;
+            break ;
+
+        case E_RESOLVE_SERVICE_LIMIT_STACK:
+            res->limit.limitstack = resolve_add_uint64(data) ;
+            break ;
+
+        default:
+            break ;
+    }
+
+    free(wres) ;
+}
+
 void service_resolve_modify_field(resolve_service_t *res, resolve_service_enum_table_t table, char const *data)
 {
     log_flow() ;
@@ -534,6 +660,10 @@ void service_resolve_modify_field(resolve_service_t *res, resolve_service_enum_t
             modify_io(res, data, table.id) ;
             break ;
 
+        case E_RESOLVE_SERVICE_CATEGORY_LIMIT:
+            modify_limit(res, data, table.id) ;
+            break ;
+
         default:
             break ;
     }
