@@ -50,7 +50,6 @@ static uint8_t reloadmsg = 0 ;
 static uint8_t PROPAGATE = 1 ;
 static ssexec_t_ref PINFO = 0 ;
 
-typedef enum fifo_e fifo_t, *fifo_t_ref ;
 enum fifo_e
 {
     FIFO_u = 0,
@@ -61,8 +60,8 @@ enum fifo_e
     FIFO_b,
     FIFO_B
 } ;
+typedef enum fifo_e fifo_t, *fifo_t_ref ;
 
-typedef enum service_action_e service_action_t, *service_action_t_ref ;
 enum service_action_e
 {
     SERVICE_ACTION_GOTIT = 0,
@@ -70,6 +69,7 @@ enum service_action_e
     SERVICE_ACTION_FATAL,
     SERVICE_ACTION_UNKNOWN
 } ;
+typedef enum service_action_e service_action_t, *service_action_t_ref ;
 
 static const unsigned char actions[2][7] = {
     // u U d D F b B
@@ -107,7 +107,7 @@ static inline void kill_all(pidservice_t *apids)
     while (j--) kill(apids[j].pid, SIGKILL) ;
 }
 
-static int check_action(pidservice_t *apids, unsigned int pos, unsigned int receive, unsigned int what)
+static int check_action(pidservice_t *apids, int pos, unsigned int receive, unsigned int what)
 {
     unsigned int p = char2enum[receive] ;
     unsigned char action = actions[what][p] ;
@@ -335,7 +335,7 @@ unsigned int compute_timeout(resolve_service_t *res, uint8_t what)
 
 }
 
-static int doit(pidservice_t *apids, unsigned int idx, uint8_t what, tain *deadline)
+static int doit(pidservice_t *apids, unsigned int idx, uint8_t what)
 {
     log_flow() ;
 
@@ -467,8 +467,8 @@ static int async_deps(pidservice_t *apids, uint32_t i, uint8_t what, tain *deadl
 {
     log_flow() ;
 
-    int r ;
-    unsigned int pos = 0, id = 0, idx = 0 ;
+    int r, id = 0 ;
+    unsigned int pos = 0, idx = 0 ;
     char buf[(UINT_FMT*2)*SS_MAX_SERVICE + 1] ;
 
     tain dead ;
@@ -513,9 +513,11 @@ static int async_deps(pidservice_t *apids, uint32_t i, uint8_t what, tain *deadl
                  * signal received.*/
                 r = get_len_until(buf + idx, '@') ;
 
-                if (r < 0)
+                if (r < 0) {
                     /* no more signal */
-                    goto next ;
+                    r = -1 ;
+                    continue ;
+                }
 
                 char line[r + 1] ;
                 memcpy(line, buf + idx, r) ;
@@ -559,7 +561,6 @@ static int async_deps(pidservice_t *apids, uint32_t i, uint8_t what, tain *deadl
                 }
             }
         }
-        next:
     }
 
     return 1 ;
@@ -585,7 +586,7 @@ static int async(pidservice_t *apids, uint32_t i, uint8_t what, tain *deadline)
                 if (!async_deps(apids, i, what, deadline))
                     log_warnu_return(LOG_EXIT_SYS, !what ? "start" : "stop", " dependencies of service: ", name) ;
 
-            e = doit(apids, i, what, deadline) ;
+            e = doit(apids, i, what) ;
 
         } else {
 
