@@ -44,7 +44,6 @@ static uint32_t napid = 0 ;
 static unsigned int npid = 0 ;
 static uint8_t reloadmsg = 0 ;
 
-typedef enum fifo_e fifo_t, *fifo_t_ref ;
 enum fifo_e
 {
     FIFO_u = 0,
@@ -55,8 +54,8 @@ enum fifo_e
     FIFO_b,
     FIFO_B
 } ;
+typedef enum fifo_e fifo_t, *fifo_t_ref ;
 
-typedef enum tree_action_e tree_action_t, *tree_action_t_ref ;
 enum tree_action_e
 {
     TREE_ACTION_GOTIT = 0,
@@ -64,6 +63,7 @@ enum tree_action_e
     TREE_ACTION_FATAL,
     TREE_ACTION_UNKNOWN
 } ;
+typedef enum tree_action_e tree_action_t, *tree_action_t_ref ;
 
 static const unsigned char actions[3][7] = {
     // u                    U                       d                       D                       F                   b                   B
@@ -102,7 +102,7 @@ static inline void kill_all(pidtree_t *apidt)
     while (j--) kill(apidt[j].pid, SIGKILL) ;
 }
 
-static int check_action(pidtree_t *apidt, unsigned int pos, unsigned int receive, unsigned int what)
+static int check_action(pidtree_t *apidt, int pos, unsigned int receive, unsigned int what)
 {
     unsigned int p = char2enum[receive] ;
     unsigned char action = actions[what][p] ;
@@ -333,7 +333,7 @@ static int ssexec_callback(stack *stk, ssexec_t *info, unsigned int what)
     return e ;
 }
 
-static int doit(pidtree_t apid, ssexec_t *info, unsigned int what, tain *deadline)
+static int doit(pidtree_t apid, ssexec_t *info, unsigned int what)
 {
     log_flow() ;
 
@@ -374,8 +374,8 @@ static int async_deps(pidtree_t *apidt, unsigned int i, unsigned int what, tain
 {
     log_flow() ;
 
-    int r ;
-    unsigned int pos = 0, id = 0, idx = 0 ;
+    int r, id = 0 ;
+    unsigned int pos = 0, idx = 0 ;
     char buf[(UINT_FMT*2)*SS_MAX_SERVICE + 1] ;
 
     tain dead ;
@@ -420,9 +420,11 @@ static int async_deps(pidtree_t *apidt, unsigned int i, unsigned int what, tain
                  * signal received.*/
                 r = get_len_until(buf + idx, '@') ;
 
-                if (r < 0)
+                if (r < 0) {
                     /* no more signal */
-                    goto next ;
+                    r = -1 ;
+                    continue ;
+                }
 
                 char line[r + 1] ;
                 memcpy(line, buf + idx, r) ;
@@ -466,8 +468,6 @@ static int async_deps(pidtree_t *apidt, unsigned int i, unsigned int what, tain
                 }
             }
         }
-        next:
-
     }
 
     return 1 ;
@@ -500,7 +500,7 @@ static int async(pidtree_t *apidt, unsigned int i, unsigned int what, ssexec_t *
                 }
             }
 
-            e = doit(apidt[i], &sinfo, what, deadline) ;
+            e = doit(apidt[i], &sinfo, what) ;
 
         } else {
 
